@@ -1,7 +1,11 @@
-pub mod algorithm;
 pub mod chrono;
+pub mod macros;
+pub mod os;
+pub mod script;
+
+#[cfg(not(feature = "wasm"))]
+pub mod algorithm;
+#[cfg(not(feature = "wasm"))]
+pub mod net;
 // pub mod compression;
 // pub mod db;
-pub mod net;
-pub mod os;
-//pub mod script;
